// Voluntary contribution institution
clear
ztree2stata institution using lecture8.xls

egen groupsize = count(contribution), by(period group)
sum punishsize
local punmax = r(max)
forvalues i=1(1)`punmax' {
	gen punishsize`i' = cond(punishsize == `i', 1/groupsize, 0)
}

graph bar (sum) punishsize1 punishsize2 punishsize3, over(period) stack bar(1, fcolor(orange) lcolor(black)) bar(2, fcolor(forest_green) lcolor(black)) bar(3, fcolor(ebblue) lcolor(black)) bar(4, fcolor(cranberry) lcolor(black)) ytitle(Number of groups) ylabel(, angle(horizontal) nogrid) caption(Period, position(6)) legend(order(1 "Size 1" 2 "Size 2" 3 "Size 3" 4 "Size 4") rows(1) region(fcolor(white) lcolor(white)) position(12)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(black) ifcolor(white) ilcolor(white)) name(institution, replace)
graph export institution.pdf, as(pdf) replace

egen avgcontribute = mean(contribution), by(period punishform)
collapse avgcontribute contribution, by(period punishform punishmember)

forvalues i=1(1)9{
	quietly tab avgcontribute if period==`i' & punishform==0
	local exist = r(N)
	if `exist' == 0{
		local nobs = _N + 1
		quietly set obs `nobs'
		quietly replace period = `i' if period == .
		quietly replace punishform = 0 if punishform == .
		quietly replace punishmember = 0 if punishmember == .
	}
}
forvalues i=1(1)9{
	quietly tab avgcontribute if period==`i' & punishform==1 & punishmember==0
	local exist = r(N)
	if `exist' == 0{
		local nobs = _N + 1
		quietly set obs `nobs'
		quietly replace period = `i' if period == .
		quietly replace punishform = 1 if punishform == .
		quietly replace punishmember = 0 if punishmember == .
	}
}
forvalues i=1(1)9{
	quietly tab avgcontribute if period==`i' & punishform==1 & punishmember==1
	local exist = r(N)
	if `exist' == 0{
		local nobs = _N + 1
		quietly set obs `nobs'
		quietly replace period = `i' if period == .
		quietly replace punishform = 1 if punishform == .
		quietly replace punishmember = 1 if punishmember == .
	}
}
sort period punishform punishmember

twoway (connected avgcontribute period if punishform==0, sort msymbol(circle) mcolor(forest_green) lcolor(forest_green) lwidth(medthick) cmissing(n)) (connected avgcontribute period if punishform==1, msymbol(circle_hollow) sort mcolor(emidblue) lcolor(emidblue) lwidth(medthick) cmissing(n)) (connected contribution period if punishform==1 & punishmember==0, sort msymbol(square_hollow) mcolor(ebblue) lcolor(ebblue) lwidth(medthick) lpattern(dash) cmissing(n)) (connected contribution period if punishform==1 & punishmember==1, sort msymbol(square) mcolor(edkblue) lcolor(edkblue) lwidth(medthick) lpattern(dash) cmissing(n)), ytitle(Mean Contribution) ylabel(0(2)20, angle(horizontal) nogrid) xtitle(Period) xlabel(1(1)9) legend(order(1 "Without institution" 2 "With institution" 3 "With institution (member)" 4 "With institution (non-member)") region(fcolor(white) lcolor(white)) position(12)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(black) ifcolor(white) ilcolor(white)) name(institutioncont, replace)
graph export institution.pdf, as(pdf) replace